@@ -31,5 +31,6 @@ The ellipses (`...`) are there to indicate that we may want to specify particula
 """
 
 
-from streamlitfront.base import dispatch_funcs, mk_app
-from streamlitfront.util import run_streamlit, data_files
+from .base import dispatch_funcs, mk_app
+from .util import run_streamlit, data_files
+from .data_binding import BoundData, binder
